pub struct Exclusive<'a, T>(pub &'a mut T);
Newtype over &'a mut T that implements the Mutex trait
The Mutex implementation for this type is a no-op: no critical section is created
The resulting type after dereferencing.
pub fn deref(&self) -> &T
Mutably dereferences the value.
Data protected by the mutex
pub fn lock<R>(&mut self, f: impl FnOnce(&mut T) -> R) -> R
Creates a critical section and grants temporary access to the protected data
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.